@@ -30,6 +30,7 @@ import shutil
 import uuid
 
 import jinja2
+from jinja2 import select_autoescape
 
 from osbenchmark import exceptions
 from osbenchmark.builder import provision_config, java_resolver
@@ -153,8 +154,8 @@ def cleanup(preserve, install_dir, data_paths):
 def _apply_config(source_root_path, target_root_path, config_vars):
     logger = logging.getLogger(__name__)
     for root, _, files in os.walk(source_root_path):
-        env = jinja2.Environment(loader=jinja2.FileSystemLoader(root))
 
+        env = jinja2.Environment(loader=jinja2.FileSystemLoader(root), autoescape=select_autoescape(['html', 'xml']))
         relative_root = root[len(source_root_path) + 1:]
         absolute_target_root = os.path.join(target_root_path, relative_root)
         io.ensure_dir(absolute_target_root)
@@ -440,7 +441,7 @@ class DockerProvisioner:
 
         for provision_config_instance_config_path in self.provision_config_instance.config_paths:
             for root, _, files in os.walk(provision_config_instance_config_path):
-                env = jinja2.Environment(loader=jinja2.FileSystemLoader(root))
+                env = jinja2.Environment(loader=jinja2.FileSystemLoader(root), autoescape=select_autoescape(['html', 'xml']))
 
                 relative_root = root[len(provision_config_instance_config_path) + 1:]
                 absolute_target_root = os.path.join(self.binary_path, relative_root)
@@ -488,7 +489,7 @@ class DockerProvisioner:
 
     def _render_template(self, loader, template_name, variables):
         try:
-            env = jinja2.Environment(loader=loader)
+            env = jinja2.Environment(loader=loader, autoescape=select_autoescape(['html', 'xml']))
             for k, v in variables.items():
                 env.globals[k] = v
             template = env.get_template(template_name)
