@@ -36,7 +36,7 @@ import time
 import zlib
 from enum import Enum, IntEnum
 from http.client import responses
-
+import opensearchpy.helpers
 import tabulate
 
 from osbenchmark import client, time, exceptions, config, version, paths
@@ -52,8 +52,8 @@ class OsClient:
         self._client = client
         self.logger = logging.getLogger(__name__)
         self._cluster_version = cluster_version
+        self._cluster_distribution = None
 
-    # TODO #653: Remove version-specific support for metrics stores before 7.0.0.
     def probe_version(self):
         info = self.guarded(self._client.info)
         try:
@@ -63,15 +63,15 @@ class OsClient:
             self.logger.exception(msg)
             raise exceptions.BenchmarkError(msg)
 
+        try:
+            self._cluster_distribution = info["version"]["distribution"]
+        except BaseException:
+            msg = "Could not determine distribution of metrics cluster, assuming elasticsearch"
+            self.logger.exception(msg)
+            self._cluster_distribution = "elasticsearch"
+
     def put_template(self, name, template):
-        # TODO #653: Remove version-specific support for metrics stores before 7.0.0 (also adjust template)
-        if self._cluster_version[0] > 6:
-            return self.guarded(self._client.indices.put_template, name=name, body=template, params={
-                # allows to include the type name although it is not allowed anymore by default
-                "include_type_name": "true"
-            })
-        else:
-            return self.guarded(self._client.indices.put_template, name=name, body=template)
+        return self.guarded(self._client.indices.put_template, name=name, body=template)
 
     def template_exists(self, name):
         return self.guarded(self._client.indices.exists_template, name)
@@ -93,13 +93,7 @@ class OsClient:
         return self.guarded(self._client.indices.refresh, index=index)
 
     def bulk_index(self, index, doc_type, items):
-        # TODO #653: Remove version-specific support for metrics stores before 7.0.0.
-        # pylint: disable=import-outside-toplevel
-        import elasticsearch.helpers
-        if self._cluster_version[0] > 6:
-            self.guarded(elasticsearch.helpers.bulk, self._client, items, index=index, chunk_size=5000)
-        else:
-            self.guarded(elasticsearch.helpers.bulk, self._client, items, index=index, doc_type=doc_type, chunk_size=5000)
+        self.guarded(opensearchpy.helpers.bulk, self._client, items, index=index, chunk_size=5000)
 
     def index(self, index, doc_type, item, id=None):
         doc = {
@@ -114,7 +108,7 @@ class OsClient:
 
     def guarded(self, target, *args, **kwargs):
         # pylint: disable=import-outside-toplevel
-        import elasticsearch
+        import opensearchpy
         max_execution_count = 11
         execution_count = 0
 
@@ -124,7 +118,7 @@ class OsClient:
 
             try:
                 return target(*args, **kwargs)
-            except elasticsearch.exceptions.AuthenticationException:
+            except opensearchpy.exceptions.AuthenticationException:
                 # we know that it is just one host (see OsClientFactory)
                 node = self._client.transport.hosts[0]
                 msg = "The configured user could not authenticate against your OpenSearch metrics store running on host [%s] at " \
@@ -132,7 +126,7 @@ class OsClient:
                       (node["host"], node["port"], config.ConfigFile().location)
                 self.logger.exception(msg)
                 raise exceptions.SystemSetupError(msg)
-            except elasticsearch.exceptions.AuthorizationException:
+            except opensearchpy.exceptions.AuthorizationException:
                 node = self._client.transport.hosts[0]
                 msg = "The configured user does not have enough privileges to run the operation [%s] against your OpenSearch metrics " \
                       "store running on host [%s] at port [%s]. Please specify a user with enough " \
@@ -140,7 +134,7 @@ class OsClient:
                       (target.__name__, node["host"], node["port"], config.ConfigFile().location)
                 self.logger.exception(msg)
                 raise exceptions.SystemSetupError(msg)
-            except elasticsearch.exceptions.ConnectionTimeout:
+            except opensearchpy.exceptions.ConnectionTimeout:
                 if execution_count < max_execution_count:
                     self.logger.debug("Connection timeout in attempt [%d/%d].", execution_count, max_execution_count)
                     time.sleep(time_to_sleep)
@@ -151,13 +145,13 @@ class OsClient:
                     msg = "A connection timeout occurred while running the operation [%s] against your OpenSearch metrics store on " \
                           "host [%s] at port [%s]." % (operation, node["host"], node["port"])
                     raise exceptions.BenchmarkError(msg)
-            except elasticsearch.exceptions.ConnectionError:
+            except opensearchpy.exceptions.ConnectionError:
                 node = self._client.transport.hosts[0]
                 msg = "Could not connect to your OpenSearch metrics store. Please check that it is running on host [%s] at port [%s]" \
                       " or fix the configuration in [%s]." % (node["host"], node["port"], config.ConfigFile().location)
                 self.logger.exception(msg)
                 raise exceptions.SystemSetupError(msg)
-            except elasticsearch.TransportError as e:
+            except opensearchpy.TransportError as e:
                 if e.status_code in (502, 503, 504, 429) and execution_count < max_execution_count:
                     self.logger.debug("%s (code: %d) in attempt [%d/%d]. Sleeping for [%f] seconds.",
                                       responses[e.status_code], e.status_code, execution_count, max_execution_count, time_to_sleep)
@@ -169,7 +163,7 @@ class OsClient:
                     self.logger.exception(msg)
                     raise exceptions.BenchmarkError(msg)
 
-            except elasticsearch.exceptions.ElasticsearchException:
+            except opensearchpy.exceptions.OpenSearchException:
                 node = self._client.transport.hosts[0]
                 msg = "An unknown error occurred while running the operation [%s] against your OpenSearch metrics store on host [%s] " \
                       "at port [%s]." % (target.__name__, node["host"], node["port"])
